/*
 * misc.c: miscellaneous functions
 * Fistgen sources.
 * Copyright (c) 1997-2000 Erez Zadok <ezk@cs.columbia.edu>
 */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */


/* lowercase a whole string (in-place) */
void
lowercase_string(char *str)
{
  char *cp = str;

  if (!str)
    return;
  do {
    *cp = tolower(*cp);
  } while (*cp++);
}


/* uppercase a whole string (in-place) */
void
uppercase_string(char *str)
{
  char *cp = str;

  if (!str)
    return;
  do {
    *cp = toupper(*cp);
  } while (*cp++);
}

#ifdef __freebsd__
/* from glibc */
char *
basename(const char *filename)
{
  char *p = strrchr (filename, '/');
  return p ? p + 1 : (char *) filename;
}


/* from glibc */
char *
dirname(char *path)
{
  static const char dot[] = ".";
  char *last_slash;

  /* Find last '/'.  */
  last_slash = path != NULL ? strrchr (path, '/') : NULL;

  if (last_slash == path)
    /* The last slash is the first character in the string.  We have to
       return "/".  */
    ++last_slash;
  else if (last_slash != NULL && last_slash[1] == '\0')
    /* The '/' is the last character, we have to look further.  */
    last_slash = memchr (path, last_slash - path, '/');

  if (last_slash != NULL)
    /* Terminate the path.  */
    last_slash[0] = '\0';
  else
    /* This assignment is ill-designed but the XPG specs require to
       return a string containing "." in any case no directory part is
       found and so a static and constant string is required.  */
    path = (char *) dot;

  return path;
}
#endif /* __freebsd__ */
